@@ -6,22 +6,23 @@ import click
 from pathlib import Path
 from future.moves import subprocess
 
-from mldock.config.config_manager import \
-    ResourceConfigManager, MLDockConfigManager, PackageConfigManager, \
-        HyperparameterConfigManager, InputDataConfigManager, WorkingDirectoryManager, \
-            EnvironmentConfigManager, StageConfigManager
-from mldock.api.local import \
-    _copy_boilerplate_to_dst, _rename_file
-from mldock.platform_helpers.utils import _write_json, _extract_data_channels_from_mldock
-
-from mldock.api.platform import sagemaker_init, generic_init
+from mldock.config_managers.core import WorkingDirectoryManager
+from mldock.config_managers.container import MLDockConfigManager
+from mldock.config_managers.cli import \
+    ResourceConfigManager, PackageConfigManager, \
+        HyperparameterConfigManager, InputDataConfigManager, StageConfigManager, \
+            ModelConfigManager, EnvironmentConfigManager
+from mldock.platform_helpers import utils
+from mldock.platform_helpers.mldock import utils as mldock_utils
+from mldock.api.container import init_container_project
 
 click.disable_unicode_literals_warning = True
 logger=logging.getLogger('mldock')
 
 
 def reset_terminal():
-    os.system("clear")
+    # os.system("clear")
+    click.clear()
 
 @click.group()
 def container():
@@ -39,7 +40,6 @@ def create_template(obj, name, dir, out):
     """
     Command to create a mldock enabled container template
     """
-    helper_library_path=obj['helper_library_path']
 
     try:
         if not Path(dir, '.mldock.json').exists():
@@ -52,13 +52,14 @@ def create_template(obj, name, dir, out):
 
         destination_src_path = Path(destination_path, 'src')
 
-        _copy_boilerplate_to_dst(mldock_src_path, destination_src_path)
+        utils._copy_boilerplate_to_dst(mldock_src_path, destination_src_path)
     except Exception as exception:
         logger.error(exception)
+        raise
 
 @click.command()
 @click.option('--dir', help='Set the working directory for your sagify container.', required=True)
-@click.option('--testing_framework', default=None, help='(Optional) Pytest framework. This creates a few health-check tests')
+@click.option('--testing-framework', default=None, help='(Optional) Pytest framework. This creates a few health-check tests')
 @click.option('--service', default=None, help='(Optional) Docker Compose. This seeds a service config.')
 @click.option('--no-prompt', is_flag=True, help='Do not prompt user, instead use the mldock config to initialize the container.')
 @click.option('--container-only', is_flag=True, help='Only inject new container assets.')
@@ -66,20 +67,23 @@ def create_template(obj, name, dir, out):
 @click.pass_obj
 def init(obj, dir, testing_framework, service, no_prompt, container_only, template):
     """
-    Command to initialize mldock enabled container
+    Command to initialize mldock enabled container project
     """
     reset_terminal()
-    helper_library_path=obj['helper_library_path']
+    mldock_package_path=obj['mldock_package_path']
     try:
-        logger.info("Initializing MLDock config")
+        click.secho("Initializing MLDock project configuration", bg='blue', nl=True)
+        prompt_input = click.confirm("File not found. Create?")
         mldock_manager = MLDockConfigManager(
-            filepath=os.path.join(dir, ".mldock.json")
+            filepath=os.path.join(dir, ".mldock.json"),
+            create=prompt_input
         )
         if not no_prompt:
             mldock_manager.setup_config()
 
         package_manager = PackageConfigManager(
-            filepath=os.path.join(dir, "requirements.txt")
+            filepath=os.path.join(dir, "requirements.txt"),
+            create=True
         )
         # write to package manager
         package_manager.write_file()
@@ -111,7 +115,14 @@ def init(obj, dir, testing_framework, service, no_prompt, container_only, templa
         )
         # set input data channels
         input_data_channels = InputDataConfigManager(
-            config=mldock_config.get('data', [])
+            config=mldock_config.get('data', []),
+            base_path=Path(dir, 'data')
+        )
+
+        # set model channels
+        model_channels = ModelConfigManager(
+            config=mldock_config.get('model', []),
+            base_path=Path(dir, 'model')
         )
 
         # set hyperparameters
@@ -126,11 +137,20 @@ def init(obj, dir, testing_framework, service, no_prompt, container_only, templa
 
         if not no_prompt:
             stage_config_manager.ask_for_stages()
+            # update stages
             mldock_manager.update_stages(stages=stage_config_manager.get_config())
+            # update input data channels
             input_data_channels.ask_for_input_data_channels()
+            input_data_channels.write_gitignore()
             mldock_manager.update_data_channels(data=input_data_channels.get_config())
+            # update model channels
+            model_channels.ask_for_model_channels()
+            model_channels.write_gitignore()
+            mldock_manager.update_model_channels(models=model_channels.get_config())
+            # update hyperparameters
             hyperparameters.ask_for_hyperparameters()
             mldock_manager.update_hyperparameters(hyperparameters=hyperparameters.get_config())
+            # update environments
             environment.ask_for_env_vars()
             mldock_manager.update_env_vars(environment=environment.get_config())
 
@@ -142,49 +162,21 @@ def init(obj, dir, testing_framework, service, no_prompt, container_only, templa
         if platform == "sagemaker":
             # get list of dataset names
             mldock_data = mldock_config.get("data", None)
-            input_config_config = _extract_data_channels_from_mldock(mldock_data)
-            _write_json(input_config_config, Path(dir,'config/inputdataconfig.json'))
-            # pass down any information like hyperparameters, etc
-            sagemaker_init(
-                dir=working_directory_manager.get_working_dir(),
-                helper_library_path=helper_library_path,
-                mldock_config=mldock_config,
-                no_prompt=no_prompt,
-                testing_framework=testing_framework,
-                service=service,
-                container_only=container_only,
-                template_dir=template
-            )
-        elif platform == "sagemakerv2":
-            # get list of dataset names
-            mldock_data = mldock_config.get("data", None)
-            input_config_config = _extract_data_channels_from_mldock(mldock_data)
-            _write_json(input_config_config, Path(dir,'config/inputdataconfig.json'))
-            sagemaker_init(
-                dir=working_directory_manager.get_working_dir(),
-                helper_library_path=helper_library_path,
-                mldock_config=mldock_config,
-                no_prompt=no_prompt,
-                testing_framework=testing_framework,
-                service=service,
-                container_only=container_only,
-                template_dir=template
-            )
-        elif platform == "generic":
-            # pass down any information like hyperparameters, etc
-            generic_init(
-                dir=working_directory_manager.get_working_dir(),
-                helper_library_path=helper_library_path,
-                mldock_config=mldock_config,
-                testing_framework=testing_framework,
-                service=service,
-                container_only=container_only,
-                template_dir=template
-            )
-        else:
-            raise Exception("Platform not found. Please supply available platform template.")
+            input_config_config = mldock_utils._extract_data_channels_from_mldock(mldock_data)
+            utils._write_json(input_config_config, Path(dir,'config/inputdataconfig.json'))
+            utils._write_json({"current_host": "dummy_host", "hosts": ["dummy_host", "second_dummy_host"]}, Path(dir,'config/resourceconfig.json'))
 
-        click.clear()
+        init_container_project(
+            dir=working_directory_manager.get_working_dir(),
+            mldock_package_path=mldock_package_path,
+            mldock_config=mldock_config,
+            testing_framework=testing_framework,
+            service=service,
+            container_only=container_only,
+            template_dir=template
+        )
+
+        reset_terminal()
         logger.info(obj["logo"])
         states = mldock_manager.get_state()
 
@@ -193,22 +185,21 @@ def init(obj, dir, testing_framework, service, no_prompt, container_only, templa
             click.echo(click.style(state["message"], fg='white'), nl=True)
 
         logger.info("\nlocal container volume is ready! ヽ(´▽`)/")
-    except subprocess.CalledProcessError as e:
-        logger.error(e.output)
-        sys.exit(-1)
-    except Exception as e:
-        logger.error("{}".format(e))
-        sys.exit(-1)
+    except subprocess.CalledProcessError as exception:
+        logger.error(exception)
+        raise
+    except Exception as exception:
+        logger.error(exception)
+        raise
 
 @click.command()
 @click.option('--dir', help='Set the working directory for your sagify container.', required=True)
 @click.pass_obj
 def update(obj, dir):
     """
-    Command to initialize container configs required by sagemaker-training.
+    Command to update mldock container.
     """
     reset_terminal()
-    helper_library_path=obj['helper_library_path']
     try:
         logger.info("Loading MLDock config")
         mldock_manager = MLDockConfigManager(
@@ -220,7 +211,7 @@ def update(obj, dir):
 
         # get list of dataset names
         mldock_data = mldock_config.get("data", None)
-        input_config_config = _extract_data_channels_from_mldock(mldock_data)
+        input_config_config = mldock_utils._extract_data_channels_from_mldock(mldock_data)
 
         src_directory = os.path.join(
             dir,
@@ -241,7 +232,13 @@ def update(obj, dir):
         )
         # set input data channels
         input_data_channels = InputDataConfigManager(
-            config=mldock_config.get('data', [])
+            config=mldock_config.get('data', []),
+            base_path=Path(dir, 'data')
+        )
+        # set model channels
+        model_channels = ModelConfigManager(
+            config=mldock_config.get('model', []),
+            base_path=Path(dir, 'model')
         )
 
         # set hyperparameters
@@ -255,11 +252,20 @@ def update(obj, dir):
         )
 
         stage_config_manager.ask_for_stages()
+        # update stages
         mldock_manager.update_stages(stages=stage_config_manager.get_config())
+        # update input data channels
         input_data_channels.ask_for_input_data_channels()
+        input_data_channels.write_gitignore()
         mldock_manager.update_data_channels(data=input_data_channels.get_config())
+        # update model channels
+        model_channels.ask_for_model_channels()
+        model_channels.write_gitignore()
+        mldock_manager.update_model_channels(models=model_channels.get_config())
+        # update hyperparameters
         hyperparameters.ask_for_hyperparameters()
         mldock_manager.update_hyperparameters(hyperparameters=hyperparameters.get_config())
+        # update environments
         environment.ask_for_env_vars()
         mldock_manager.update_env_vars(environment=environment.get_config())
 
@@ -272,7 +278,7 @@ def update(obj, dir):
             # get list of dataset names
             mldock_data = mldock_config.get("data", None)
             input_config_config = _extract_data_channels_from_mldock(mldock_data)
-            _write_json(input_config_config, Path(dir,'config/inputdataconfig.json'))
+            utils._write_json(input_config_config, Path(dir,'config/inputdataconfig.json'))
 
         click.clear()
         logger.info(obj["logo"])
@@ -283,19 +289,19 @@ def update(obj, dir):
             click.echo(click.style(state["message"], fg='white'), nl=True)
 
         logger.info("\nlocal container was updated! ヽ(´▽`)/")
-    except subprocess.CalledProcessError as e:
-        logger.error(e.output)
-        sys.exit(-1)
-    except Exception as e:
-        logger.error("{}".format(e))
-        sys.exit(-1)
+    except subprocess.CalledProcessError as exception:
+        logger.error(exception)
+        raise
+    except Exception as exception:
+        logger.error(exception)
+        raise
 
 @click.command()
 @click.option('--dir', help='Set the working directory for your sagify container.', required=True)
 @click.pass_obj
 def summary(obj, dir):
     """
-    Command to initialize container configs required by sagemaker-training.
+    Command to show summary for mldock container
     """
     try:
         logger.info("Loading MLDock config")
@@ -310,12 +316,12 @@ def summary(obj, dir):
             click.echo(click.style(state["message"], fg='white'), nl=True)
 
         logger.info("\nlocal container was updated! ヽ(´▽`)/")
-    except Exception as e:
-        logger.error("{}".format(e))
-        sys.exit(-1)
+    except Exception as exception:
+        logger.error(exception)
+        raise
 
 def add_commands(cli):
-
+    """add cli commands to group"""
     cli.add_command(init)
     cli.add_command(update)
     cli.add_command(create_template)
