@@ -7,17 +7,12 @@ from pathlib import Path
 from future.moves import subprocess
 
 import mldock.api.predict as predict_request
-from mldock.platform_helpers.mldock.utils import \
-    collect_mldock_environment_variables
-from mldock.config.config_manager import \
-    ResourceConfigManager, MLDockConfigManager, PackageConfigManager, \
-        HyperparameterConfigManager, InputDataConfigManager
+from mldock.terminal import \
+    ChoiceWithNumbers, style_dropdown, style_2_level_detail
+from mldock.platform_helpers.mldock import utils as mldock_utils
+from mldock.config_managers.container import MLDockConfigManager
 from mldock.api.local import \
-    _copy_boilerplate_to_dst, docker_build, \
-        _rename_file
-
-from mldock.api.local import \
-    train_model, deploy_model
+    search_mldock_containers, docker_build, train_model, deploy_model
 
 click.disable_unicode_literals_warning = True
 logger=logging.getLogger('mldock')
@@ -25,7 +20,7 @@ logger=logging.getLogger('mldock')
 @click.group()
 def local():
     """
-    Commands for local operations: train and deploy
+    Commands for local development
     """
     pass
 
@@ -54,13 +49,13 @@ def pretty_build_logs(line: dict):
 def build(obj, dir, no_cache, tag, stage):
     """Command to build container locally
     """
-    helper_library_path = obj['helper_library_path']
     mldock_manager = MLDockConfigManager(
         filepath=os.path.join(dir, ".mldock.json")
     )
     # get mldock_module_dir name
     mldock_config = mldock_manager.get_config()
     image_name = mldock_config.get("image_name", None)
+    platform_name = mldock_config.get("platform", None)
     container_dir = mldock_config.get("container_dir", None)
     module_path = os.path.join(
         dir,
@@ -86,10 +81,10 @@ def build(obj, dir, no_cache, tag, stage):
             raise Exception("tag is not valid. Either choose a stage or set a tag manually")
     except KeyError as exception:
         logger.error("Stage not found. Either update stages in mldock config or manually set docker tag.")
-        sys.exit(-1)
+        raise
     except Exception as exception:
         logger.error(exception)
-        sys.exit(-1)
+        raise
 
     try:
         logger.info("\nStarting build...\n")
@@ -100,15 +95,16 @@ def build(obj, dir, no_cache, tag, stage):
             target_dir_name=mldock_config.get("mldock_module_dir", "src"),
             requirements_file_path=requirements_file_path,
             no_cache=no_cache,
-            docker_tag=tag
+            docker_tag=tag,
+            container_platform=platform_name
         )
         logger.info("\nBuild Complete! ヽ(´▽`)/\n")
-    except subprocess.CalledProcessError as e:
-        logger.error(e.output)
-        sys.exit(-1)
-    except Exception as e:
-        logger.error("{}".format(e))
-        sys.exit(-1)
+    except subprocess.CalledProcessError as exception:
+        logger.error(exception)
+        raise
+    except Exception as exception:
+        logger.error(exception)
+        raise
 
 @click.command()
 @click.option('--payload', default=None, help='path to payload file', required=True)
@@ -130,16 +126,16 @@ def predict(payload, content_type, host):
                 raise Exception("Content-type is not supported.")
             logger.info(pretty_output)
             logger.info("\nPrediction Complete! ヽ(´▽`)/")
-    except Exception as e:
-        logger.error("{}".format(e))
-        sys.exit(-1)
+    except Exception as exception:
+        logger.error(exception)
+        raise
 
 @click.command()
 @click.option('--dir', help='Set the working directory for your mldock container.', required=True)
 @click.option(
     '--params',
     '-p',
-    help='(Optional) Hyperparameter override used in experiment.',
+    help='(Optional) Hyperparameter override when running container.',
     nargs=2,
     type=click.Tuple([str, str]),
     multiple=True
@@ -147,7 +143,7 @@ def predict(payload, content_type, host):
 @click.option(
     '--env_vars',
     '-e',
-    help='(Optional) Hyperparameter override used in experiment.',
+    help='(Optional) Hyperparameter override when running container.',
     nargs=2,
     type=click.Tuple([str, str]),
     multiple=True
@@ -171,7 +167,6 @@ def train(obj, dir, params, env_vars, tag, stage):
     image_name = mldock_config.get("image_name", None)
     platform = mldock_config.get("platform", None)
     container_dir = mldock_config.get("container_dir", None)
-    helper_library_path = obj['helper_library_path']
 
     try:
         stages = mldock_config.get("stages", None)
@@ -207,57 +202,38 @@ def train(obj, dir, params, env_vars, tag, stage):
             {key_: value_}
         )
 
-    env_vars = collect_mldock_environment_variables(
+    env_vars = mldock_utils.collect_mldock_environment_variables(
         stage=stage,
         hyperparameters=hyperparameters,
         **project_env_vars
     )
     try:
-        if platform == "sagemaker":
-            train_model(
-                working_dir=dir,
-                docker_tag=tag,
-                image_name=image_name,
-                entrypoint="container/executor.sh",
-                cmd="train",
-                env=env_vars
-            )
-        elif platform == "sagemakerv2":
-            train_model(
-                working_dir=dir,
-                docker_tag=tag,
-                image_name=image_name,
-                entrypoint="src/container/executor.sh",
-                cmd="train",
-                env=env_vars
-            )
-        else:
-            train_model(
-                working_dir=dir,
-                docker_tag=tag,
-                image_name=image_name,
-                entrypoint="src/container/executor.sh",
-                cmd="train",
-                env=env_vars
-            )
+        train_model(
+            working_dir=dir,
+            docker_tag=tag,
+            image_name=image_name,
+            entrypoint="src/container/executor.sh",
+            cmd="train",
+            env=env_vars
+        )
 
         logger.info("Local training completed successfully!")
     except ValueError:
         logger.error("This is not a mldock directory: {}".format(dir))
-        sys.exit(-1)
-    except subprocess.CalledProcessError as e:
-        logger.error(e.output)
-        sys.exit(-1)
-    except Exception as e:
-        logger.error("{}".format(e))
-        sys.exit(-1)
+        raise
+    except subprocess.CalledProcessError as exception:
+        logger.error(exception)
+        raise
+    except Exception as exception:
+        logger.error(exception)
+        raise
 
 @click.command()
 @click.option('--dir', help='Set the working directory for your mldock container.', required=True)
 @click.option(
     '--params',
     '-p',
-    help='(Optional) Hyperparameter override used in experiment.',
+    help='(Optional) Hyperparameter override when running container.',
     nargs=2,
     type=click.Tuple([str, str]),
     multiple=True
@@ -265,7 +241,7 @@ def train(obj, dir, params, env_vars, tag, stage):
 @click.option(
     '--env_vars',
     '-e',
-    help='(Optional) Hyperparameter override used in experiment.',
+    help='(Optional) Hyperparameter override when running container.',
     nargs=2,
     type=click.Tuple([str, str]),
     multiple=True
@@ -278,7 +254,6 @@ def deploy(obj, dir, params, env_vars, tag, port, stage):
     """
     Command to deploy ml container on localhost
     """
-    helper_library_path=obj['helper_library_path']
     mldock_manager = MLDockConfigManager(
         filepath=os.path.join(dir, ".mldock.json")
     )
@@ -291,7 +266,6 @@ def deploy(obj, dir, params, env_vars, tag, port, stage):
     image_name = mldock_config.get("image_name", None)
     platform = mldock_config.get("platform", None)
     container_dir = mldock_config.get("container_dir", None)
-    helper_library_path = obj['helper_library_path']
 
     try:
         stages = mldock_config.get("stages", None)
@@ -326,55 +300,85 @@ def deploy(obj, dir, params, env_vars, tag, port, stage):
             {key_: value_}
         )
 
-    env_vars = collect_mldock_environment_variables(
+    env_vars = mldock_utils.collect_mldock_environment_variables(
         stage=stage,
         hyperparameters=mldock_config.get('hyperparameters', {}),
         **project_env_vars
     )
     try:
         logger.info("Started local deployment at {}...\n".format(port))
-        if platform == "sagemaker":
-            deploy_model(
-                working_dir=dir,
-                docker_tag=tag,
-                image_name=image_name,
-                port=port,
-                entrypoint="container/executor.sh",
-                cmd="serve",
-                env=env_vars
-            )
-        elif platform == "sagemakerv2":
-            deploy_model(
-                working_dir=dir,
-                docker_tag=tag,
-                image_name=image_name,
-                port=port,
-                entrypoint="src/container/executor.sh",
-                cmd="serve",
-                env=env_vars
-            )
-        else:
-            deploy_model(
-                working_dir=dir,
-                docker_tag=tag,
-                image_name=image_name,
-                port=port,
-                entrypoint="src/container/executor.sh",
-                cmd="serve",
-                env=env_vars
-            )
+        deploy_model(
+            working_dir=dir,
+            docker_tag=tag,
+            image_name=image_name,
+            port=port,
+            entrypoint="src/container/executor.sh",
+            cmd="serve",
+            env=env_vars
+        )
 
     except ValueError:
         logger.error("This is not a mldock directory: {}".format(dir))
-        sys.exit(-1)
-    except subprocess.CalledProcessError as e:
-        logger.error(e.output)
-        sys.exit(-1)
-    except Exception as e:
-        logger.error("{}".format(e))
-        sys.exit(-1)
+        raise
+    except subprocess.CalledProcessError as exception:
+        logger.error(exception)
+        raise
+    except Exception as exception:
+        logger.error(exception)
+        raise
+
+@click.command()
+def stop():
+    """
+    Command to stop ml container on localhost
+    """
+
+    try:
+        containers = search_mldock_containers()
+
+        tags = [
+            style_2_level_detail(
+                major_detail=c.image.tags[0],
+                minor_detail=c.name
+             ) for c in containers
+        ] + ['abort']
+        # newline break
+        click.echo("")
+        click.secho("Running MLDock containers:", bg='blue', nl=True)
+        container_tag = click.prompt(
+            text=style_dropdown(group_name="container name", options=tags, default='abort'),
+            type=ChoiceWithNumbers(tags, case_sensitive=False),
+            show_default=False,
+            default='abort',
+            show_choices=False
+        )
+        project_container = None
+        for c in containers:
+            for image_tag in c.image.tags:
+                if image_tag in container_tag:
+                    # make newline
+                    click.echo("")
+                    project_container_tag = click.style(container_tag, fg='bright_blue')
+                    if click.confirm(
+                        "Stop the running container = {}?".format(
+                            project_container_tag) 
+                    ):
+                        c.kill()
+
+                    break
+
+    except ValueError:
+        logger.error("This is not a mldock directory: {}".format(dir))
+        raise
+    except subprocess.CalledProcessError as exception:
+        logger.error(exception)
+        raise
+    except Exception as exception:
+        logger.error(exception)
+        raise
 
 local.add_command(build)
 local.add_command(predict)
 local.add_command(train)
 local.add_command(deploy)
+local.add_command(stop)
