@@ -1,11 +1,14 @@
 """
     Docker Auth Utilities aand workflows
 """
+import os
 import logging
 from urllib.parse import urlparse
 import docker
 
 from mldock.platform_helpers.aws.auth import get_aws_ecr
+from mldock.platform_helpers.gcp.auth import get_gcp_gcr
+from mldock.platform_helpers.dockerhub.auth import get_dockerhub_credentials
 
 logger=logging.getLogger('mldock')
 
@@ -22,7 +25,15 @@ def login_and_authenticate(provider: str, region: str):
 
     if provider == 'ecr':
         # AWS ECR
-        username, password, registry = get_aws_ecr(region=region)
+        username, password, registry, repo = get_aws_ecr(region=region)
+    elif provider == 'gcr':
+        # GCP 
+        username, password, registry, repo = get_gcp_gcr(region=region)
+    elif provider == 'dockerhub':
+        # DockerHub
+        username, password, registry, repo = get_dockerhub_credentials()
+    else:
+        raise TypeError("{PROVIDER} Registry is not implemented.".format(PROVIDER=provider))
 
     # login
     response = client.login(
@@ -34,7 +45,11 @@ def login_and_authenticate(provider: str, region: str):
     )
 
     logger.debug("Login Response = {}".format(response))
-    cloud_repository = urlparse(registry).netloc
 
     # return logged in client
-    return client, {'username': username,'password': password,'registry': registry, 'repository': cloud_repository}
+    return client, {
+        'username': username,
+        'password': password,
+        'registry': registry,
+        'repository': repo
+    }
