@@ -5,111 +5,16 @@
     E.g. cloud storage tools to upload and download objects.
 """
 import os
-import glob
-from google.cloud import storage
 from pathlib import Path
-import tarfile
-import zipfile
-from typing import Iterator
 import logging
-from urllib.parse import urlparse
+from google.cloud import storage
 
-logging.basicConfig(level=logging.INFO)
-logger = logging.getLogger(None)
-logger.setLevel(logging.INFO)
+from mldock.platform_helpers.utils import \
+    _delete_file, _mkdir, _iter_nested_dir, _check_if_cloud_scheme, \
+        parse_url, zip_folder_as_tarfile, zip_folder, \
+         unzip_file_from_tarfile, unzip_file
 
-def _mkdir(dir_path: str):
-    """make directory structure
-
-    Args:
-        dir_path (str): directory path to build
-    """
-    p = Path(dir_path)
-    p.mkdir(parents=True, exist_ok=True)
-
-def _iter_nested_dir(root_dir: str) -> Iterator[str]:
-    """Iterate through nested folders.
-
-    Args:
-        root_dir (str): name of the directory to start form
-
-    Yields:
-        Iterator[str]: path iterator
-    """
-    rootdir = Path(root_dir)
-    for path in rootdir.glob('**/*'):
-        yield path
-
-def _delete_file(file_path):
-    """Delete a file
-
-    Args:
-        file_path (str): path to file
-
-    Raises:
-        TypeError: Expected a file_path of type file. Cannot be directory or other.
-    """
-    path = Path(file_path)
-    if not path.is_file():
-        raise TypeError("Expected a file_path of type file. Only deletes files")
-
-    os.remove(path)
-
-def _check_if_cloud_scheme(url: str, scheme: str = 's3') -> bool:
-    parsed_url = urlparse(url)
-    return parsed_url.scheme == scheme
-
-def parse_url(url: str, scheme: str = 's3'):
-    """Returns an (s3 bucket, key name/prefix) tuple from a url with an s3
-    scheme.
-    Args:
-        url (str):
-    Returns:
-        tuple: A tuple containing:
-            - str: S3 bucket name
-            - str: S3 key
-    """
-    parsed_url = urlparse(url)
-    if parsed_url.scheme != scheme:
-        raise ValueError("Expecting '{}' scheme, got: {} in {}.".format(scheme, parsed_url.scheme, url))
-    return parsed_url.netloc, parsed_url.path.lstrip("/")
-
-def zip_folder(dir_path, output_file, rm_original=True):
-    """zip in directory and optionally throw away unzipped"""
-
-    with zipfile.ZipFile(output_file, 'w', zipfile.ZIP_DEFLATED) as zipf:
-        for file in _iter_nested_dir(dir_path):
-            if file.name != Path(output_file).name and file.is_file():
-                zipf.write(os.path.join(file), arcname=file.relative_to(dir_path))
-                if rm_original:
-                    _delete_file(file)
-
-def zip_folder_as_tarfile(dir_path, output_file, rm_original=True):
-    """zip folder as tarfile and optionally throw away original files"""
-    with tarfile.open(output_file, "w:gz") as tar:
-        for file in _iter_nested_dir(dir_path):
-            if file.name != Path(output_file).name and file.is_file():
-                tar.add(file, arcname=file.relative_to(dir_path))
-                if rm_original:
-                    _delete_file(file)
-
-def unzip_file(filename, output_dir, rm_zipped=True):
-    """unzip in directory and optionally throw away zipped"""
-    with zipfile.ZipFile(filename, 'r', zipfile.ZIP_DEFLATED) as zipf:
-        logger.info("Unzipping {} => {}".format(filename, output_dir))
-        zipf.extractall(output_dir)
-        if rm_zipped:
-            logger.info("Removing {}".format(filename))
-            _delete_file(filename)
-
-def unzip_file_from_tarfile(filename, output_dir, rm_zipped=True):
-    """untar in directory and optionally throw away zipped"""
-    with tarfile.open(filename, "r:gz") as tar:
-        logger.info("Zipping {} => {}".format(filename, output_dir))
-        tar.extractall(output_dir)
-        if rm_zipped:
-            logger.info("Removing {}".format(filename))
-            _delete_file(filename)
+logger = logging.getLogger('mldock')
 
 def download_folder(
     bucket_name: str,
@@ -154,7 +59,9 @@ def upload_folder(local_path: str, bucket_name: str, prefix: str):
     # get bucket
     storage_client = storage.Client()
     bucket = storage_client.get_bucket(bucket_name)
-    assert os.path.isdir(local_path)
+
+    assert os.path.isdir(local_path), "'{}' is not a directory".format(local_path)
+
     for path in _iter_nested_dir(local_path):
         filepath = path.relative_to(local_path)
         storage_destination = os.path.join(prefix, filepath)
@@ -177,6 +84,12 @@ def download_input_assets(storage_dir_path: str, local_path: str, scheme: str =
         # download data if cloud storage path
         bucket, prefix = parse_url(url=storage_dir_path, scheme=scheme)
         download_folder(bucket_name=bucket, prefix=prefix, target=local_path)
+
+        for file_path in Path(local_path).glob('*/*'):
+            if file_path.suffix == '.zip':
+                unzip_file(filename=file_path, output_dir=file_path.parent, rm_zipped=True)
+            elif file_path.suffix == '.gz':
+                unzip_file_from_tarfile(filename=file_path, output_dir=file_path.parent, rm_zipped=True)
     else:
         Exception("No Cloud storage url was found. Must have gs:// schema")
 
