@@ -8,8 +8,8 @@ import os
 import json
 import sys
 import traceback
-from src.trainer import run_training, logger
-from src.assets import TrainingContainer
+from src.trainer import run_training
+from src.container.assets import TrainingContainer, environment, logger
 
 def train_function():
     """
@@ -21,25 +21,25 @@ def train_function():
 
     """
 
-    logger.debug("\n\n --- Running Training Script ---\n\n")
+    logger.info("\n\n --- Running Training Script ---\n\n")
     try:
 
         # custom recommender training code
         run_training()
 
-        logger.debug('Training complete.')
+        logger.info('Training complete.')
     except Exception as e:
         # Write out an error file. This will be returned as the failureReason in the
         # DescribeTrainingJob result.
         trc = traceback.format_exc()
-        with open(os.path.join('/opt/ml/output', 'failure'), 'w') as s:
+        with open(os.path.join('/opt/ml/output/errors', 'log.txt'), 'w') as s:
             s.write('Exception during training: ' + str(e) + '\n' + trc)
         # Printing this causes the exception to be in the training job logs, as well.
         logger.error('Exception during training: ' + str(e) + '\n' + trc)
 
 if __name__ == '__main__':
 
-    training = TrainingContainer()
+    training = TrainingContainer(environment=environment)
     try:
         training.startup()
 
