@@ -7,7 +7,8 @@ import os
 import json
 import sys
 import traceback
-from trainer import run_training
+from src.trainer import run_training
+from src.container.assets import TrainingContainer, environment, logger
 
 def train_function():
     """
@@ -19,27 +20,36 @@ def train_function():
 
     """
 
-    # TODO: Write your modeling logic
-    print('Starting the training.')
+    logger.info('Starting the training.')
     try:
 
         # custom recommender training code
         run_training()
 
-        print('Training complete.')
+        logger.info('Training complete.')
     except Exception as e:
         # Write out an error file. This will be returned as the failureReason in the
         # DescribeTrainingJob result.
         trc = traceback.format_exc()
-        with open(os.path.join('/opt/ml/output', 'failure'), 'w') as s:
+        with open(os.path.join('/opt/ml/output/errors', 'log.txt'), 'w') as s:
             s.write('Exception during training: ' + str(e) + '\n' + trc)
         # Printing this causes the exception to be in the training job logs, as well.
-        print('Exception during training: ' + str(e) + '\n' + trc, file=sys.stderr)
+        logger.error('Exception during training: ' + str(e) + '\n' + trc, file=sys.stderr)
         # A non-zero exit code causes the training job to be marked as Failed.
         sys.exit(255)
 
 if __name__ == '__main__':
-    train_function()
+
+    training = TrainingContainer(environment=environment)
+    try:
+        training.startup()
+
+        train_function()
+    except Exception as exception:
+        logger.error(exception)
+    finally:
+        training.cleanup()
 
     # A zero exit code causes the job to be marked a Succeeded.
+    # keep for sagemaker
     sys.exit(0)
